@@ -29,7 +29,7 @@
 |
 |  This product is not supported/written/published by Apple!
 |
-|  $Id: itdb.h 2193 2009-01-03 02:58:02Z tmzullinger $
+|  $Id: itdb.h 2272 2009-03-14 18:02:16Z teuf $
 */
 
 #ifndef __ITUNESDB_H__
@@ -1748,8 +1748,10 @@ void itdb_device_set_sysinfo (Itdb_Device *device,
 const Itdb_IpodInfo *itdb_device_get_ipod_info (const Itdb_Device *device);
 const Itdb_IpodInfo *itdb_info_get_ipod_info_table (void);
 gboolean itdb_device_supports_artwork (const Itdb_Device *device);
+gboolean itdb_device_supports_chapter_image (const Itdb_Device *device);
 gboolean itdb_device_supports_video (const Itdb_Device *device);
 gboolean itdb_device_supports_photo (const Itdb_Device *device);
+gboolean itdb_device_supports_podcast (const Itdb_Device *device);
 const gchar *itdb_info_get_ipod_model_name_string (Itdb_IpodModel model);
 const gchar *itdb_info_get_ipod_generation_string (Itdb_IpodGeneration generation);
 
